Use from C++
========================

There are a few different way to use aare in your C++ project. Which one you choose 
depends on how you intend to work with the library and how you manage your dependencies.


Install and use cmake with find_package(aare)
-------------------------------------------------

https://github.com/slsdetectorgroup/aare-examples

.. include:: _install.rst


Use as a submodule
------------------- 

Coming soon...